@@ -53,12 +53,15 @@ class Monitor:
 
     def run(self, logs_path='/var/log/event/control_log/', host='0.0.0.0', port=5000):
         log_init('health_monitor', debug=False, log_path=logs_path)
+        try:
 
-        t1 = threading.Thread(target=self.start_scheduler)
-        t2 = threading.Thread(target=self.api_run, args=[host, port])
+            t1 = threading.Thread(target=self.start_scheduler)
+            t2 = threading.Thread(target=self.api_run, args=[host, port])
 
-        t1.start()
-        t2.start()
+            t1.start()
+            t2.start()
+        except Exception as e:
+            log.info(e)
 
 
     def api_run(self, host, port):
